# V1alpha1ValueFrom

ValueFrom describes a location in which to obtain the value to a parameter
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**jq_filter** | **str** | JQFilter expression against the resource object in resource templates | [optional] 
**json_path** | **str** | JSONPath of a resource to retrieve an output parameter value from in resource templates | [optional] 
**parameter** | **str** | Parameter reference to a step or dag task in which to retrieve an output parameter value from (e.g. &#39;{{steps.mystep.outputs.myparam}}&#39;) | [optional] 
**path** | **str** | Path in the container to retrieve an output parameter value from in container templates | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


